@@ -5,6 +5,6 @@ from .file_system_input_device import (FileSystemInputDeviceManager,
 from .file_system_output_device import (FileSystemOutputDeviceManager,
                                         FileSystemOutputDevice)
 
-from .file_system_serializer import (FileSystemSerializerBase,
+from .file_system_serializer import (ZIPFileSystemSerializer,
                                      DefaultFileSystemSerializer,
                                      NoHeadersFileSystemSerializer)
